@@ -1,5 +1,5 @@
 /* Unit testing.
-   Copyright (C) 2005-2011, 2015, 2018-2019 Free Software Foundation,
+   Copyright (C) 2005-2011, 2015, 2018-2023 Free Software Foundation,
    Inc.
 
 This file is part of GNU Wget.
@@ -37,7 +37,7 @@ as that of the covered work.  */
 
 #include "unit-tests.h"
 
-const char *program_argstring = "TEST";
+extern const char *program_argstring;
 
 static int tests_run;
 
@@ -65,11 +65,12 @@ all_tests(void)
   mu_run_test (test_hsts_url_rewrite_congruent);
   mu_run_test (test_hsts_read_database);
 #endif
+  mu_run_test (test_parse_netrc);
 
   return NULL;
 }
 
-const char *program_name; /* Needed by lib/error.c. */
+extern const char *program_name; /* Needed by lib/error.c. */
 
 int
 main (int argc _GL_UNUSED, const char *argv[])
